@@ -69,6 +69,15 @@ if issue_an_error_message
     error('Estimation::mcmc::diagnostics: I cannot proceed because some MCMC files are missing. Check your MCMC files...')
 end
 
+PastDraws = sum(record.MhDraws,1);
+LastFileNumber = PastDraws(2);
+LastLineNumber = record.MhDraws(end,3);
+NumberOfDraws  = PastDraws(1);
+
+if NumberOfDraws<=2000
+    warning(['estimation:: MCMC convergence diagnostics are not computed because the total number of iterations is less than 2000!'])
+    return
+end
 
 if nblck == 1 % Brooks and Gelman tests need more than one block
     convergence_diagnostics_geweke=zeros(npar,4+2*length(options_.convergence.geweke.taper_steps));
@@ -78,8 +87,8 @@ if nblck == 1 % Brooks and Gelman tests need more than one block
         options_.convergence.geweke.geweke_interval=[0.2 0.5];
     end
     first_obs_begin_sample = max(1,ceil(options_.mh_drop*options_.mh_replic));
-    last_obs_begin_sample = first_obs_begin_sample+round(options_.convergence.geweke.geweke_interval(1)*options_.mh_replic*options_.mh_drop);
-    first_obs_end_sample = first_obs_begin_sample+round(options_.convergence.geweke.geweke_interval(2)*options_.mh_replic*options_.mh_drop);
+    last_obs_begin_sample = first_obs_begin_sample+round(options_.convergence.geweke.geweke_interval(1)*options_.mh_replic*(1-options_.mh_drop));
+    first_obs_end_sample = first_obs_begin_sample+round(options_.convergence.geweke.geweke_interval(2)*options_.mh_replic*(1-options_.mh_drop));
     param_name=[];
     for jj=1:npar
         param_name = strvcat(param_name,get_the_name(jj,options_.TeX,M_,estim_params_,options_));
@@ -121,11 +130,6 @@ if nblck == 1 % Brooks and Gelman tests need more than one block
     return;
 end
 
-PastDraws = sum(record.MhDraws,1);
-LastFileNumber = PastDraws(2);
-LastLineNumber = record.MhDraws(end,3);
-NumberOfDraws  = PastDraws(1);
-
 Origin = 1000;
 StepSize = ceil((NumberOfDraws-Origin)/100);% So that the computational time does not 
 ALPHA = 0.2;                                % increase too much with the number of simulations. 
