@@ -4,7 +4,7 @@ function x0=dynare_sensitivity(options_gsa)
 % Reference:
 % M. Ratto, Global Sensitivity Analysis for Macroeconomic models, MIMEO, 2006.
 
-% Copyright (C) 2008-2011 Dynare Team
+% Copyright (C) 2008-2013 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -31,6 +31,7 @@ lgy_ = M_.endo_names;
 x0=[];
 
 options_gsa = set_default_option(options_gsa,'datafile',[]);
+options_gsa = set_default_option(options_gsa,'rmse',0);
 if isfield(options_gsa,'nograph'),
     options_.nograph=options_gsa.nograph;
 end
@@ -46,7 +47,14 @@ end
 
 options_.order = 1;
 
-if ~isempty(options_gsa.datafile) || isempty(bayestopt_),
+if ~isempty(options_gsa.datafile) || isempty(bayestopt_) || options_gsa.rmse,
+    if isempty(options_gsa.datafile) && options_gsa.rmse,
+        disp('The data file and all relevant estimation options ')
+        disp('[first_obs, nobs, presample, prefilter, loglinear, lik_init, kalman_algo, ...]')
+        disp('must be specified for RMSE analysis!');
+        error('Sensitivity anaysis error!');
+    end
+    
     options_.datafile = options_gsa.datafile;
     if isfield(options_gsa,'first_obs'),
         options_.first_obs=options_gsa.first_obs;
@@ -72,8 +80,7 @@ if ~isempty(options_gsa.datafile) || isempty(bayestopt_),
     options_.mode_compute = 0;
     options_.filtered_vars = 1;
     options_.plot_priors = 0;
-%     [data,rawdata,xparam1,data_info]=dynare_estimation_init([],fname_,1);
-    [dataset_,xparam1, M_, options_, oo_, estim_params_,bayestopt_]=dynare_estimation_init(M_.endo_names,fname_,1, M_, options_, oo_, estim_params_, bayestopt_);
+    [dataset_,xparam1,hh, M_, options_, oo_, estim_params_,bayestopt_]=dynare_estimation_init(M_.endo_names,fname_,1, M_, options_, oo_, estim_params_, bayestopt_);
     % computes a first linear solution to set up various variables
 else
     if isempty(options_.qz_criterium)
@@ -142,7 +149,6 @@ options_gsa = set_default_option(options_gsa,'namendo',[]);
 options_gsa = set_default_option(options_gsa,'namlagendo',[]);
 options_gsa = set_default_option(options_gsa,'namexo',[]);
 % RMSE mapping
-options_gsa = set_default_option(options_gsa,'rmse',0);
 options_gsa = set_default_option(options_gsa,'lik_only',0);
 options_gsa = set_default_option(options_gsa,'var_rmse',options_.varobs);
 options_gsa = set_default_option(options_gsa,'pfilt_rmse',0.1);
@@ -208,7 +214,7 @@ if (options_gsa.load_stab || options_gsa.load_rmse || options_gsa.load_redform)
                     any(bayestopt_.p4(~isnan(bayestopt_.p4))~=bkpprior.p4(~isnan(bkpprior.p4))),
                 disp('WARNING!')
                 disp('The saved sample has different priors w.r.t. to current ones!!')
-                disp('')
+                skipline()
                 disp('Press ENTER to continue')
                 pause;
             end
@@ -219,7 +225,7 @@ end
 if options_gsa.stab && ~options_gsa.ppost,
     x0 = stab_map_(OutputDirectoryName,options_gsa);
     if isempty(x0),
-        disp(' ')
+        skipline()
         disp('Sensitivity computations stopped: no parameter set provided a unique solution')
         return
     end
@@ -260,13 +266,13 @@ if options_gsa.redform && ~isempty(options_gsa.namendo),% ...
         x0 = stab_map_(OutputDirectoryName,options_gsa);
     end
     if strmatch(':',options_gsa.namendo,'exact'),
-        options_gsa.namendo=M_.endo_names;
+        options_gsa.namendo=M_.endo_names(1:M_.orig_endo_nbr,:);
     end
     if strmatch(':',options_gsa.namexo,'exact'),
         options_gsa.namexo=M_.exo_names;
     end
     if strmatch(':',options_gsa.namlagendo,'exact'),
-        options_gsa.namlagendo=M_.endo_names;
+        options_gsa.namlagendo=M_.endo_names(1:M_.orig_endo_nbr,:);
     end
 %     options_.opt_gsa = options_gsa;
     if options_gsa.morris==1,
@@ -275,10 +281,12 @@ if options_gsa.redform && ~isempty(options_gsa.namendo),% ...
         % check existence of the SS_ANOVA toolbox
         if isempty(options_gsa.threshold_redform) && ...
          ~(exist('gsa_sdp','file')==6 || exist('gsa_sdp','file')==2),
-            disp('Download Mapping routines at:')
-            disp('http://eemc.jrc.ec.europa.eu/softwareDYNARE-Dowload.htm')
-            disp(' ' )
-            error('Mapping routines missing!')
+            fprintf('\nThe "SS-ANOVA-R: MATLAB Toolbox for the estimation of Smoothing Spline ANOVA models with Recursive algorithms" is missing.\n')
+            fprintf('To obtain it, go to:\n\n')
+            fprintf('http://ipsc.jrc.ec.europa.eu/?id=790 \n\n')
+            fprintf('and follow the instructions there.\n')
+            fprintf('After obtaining the files, you need to unpack them and set a Matlab Path to those files.\n')
+            error('SS-ANOVA-R Toolbox missing!')
         end
 
         redform_map(OutputDirectoryName,options_gsa);
@@ -294,7 +302,7 @@ if options_gsa.rmse,
         else
             a=whos('-file',[OutputDirectoryName,'/',fname_,'_mc'],'logpo2');
         end
-        if exist('OCTAVE_VERSION'),
+        if isoctave
             aflag=0;
             for ja=1:length(a),
                 aflag=aflag+strcmp('logpo2',a(ja).name);
@@ -354,7 +362,7 @@ if options_gsa.rmse,
     end
     clear a;
 %     filt_mc_(OutputDirectoryName,data_info);
-    filt_mc_(OutputDirectoryName,options_gsa);
+    filt_mc_(OutputDirectoryName,options_gsa,dataset_);
 end
 options_.opt_gsa = options_gsa;
 
