@@ -17,7 +17,7 @@ function dyn_data_01=read_variables(file_name_01,var_names_01,dyn_data_01,xls_sh
 % all local variables have complicated names in order to avoid name
 % conflicts with possible user variable names
 
-% Copyright (C) 2005-2012 Dynare Team
+% Copyright (C) 2005-2013 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -54,8 +54,10 @@ if isempty(extension)
         extension = '.xls';
     elseif exist([basename '.xlsx'],'file')
         extension = '.xlsx';
+    elseif exist([basename '.csv'],'file')
+        extension = '.csv';
     else
-        error(['Can''t find datafile: ' basename '.{m,mat,xls,xlsx}']);
+        error(['Can''t find datafile: ' basename '.{m,mat,xls,xlsx,csv}']);
     end
 end
 
@@ -87,15 +89,37 @@ switch (extension)
             dyn_data_01(:,dyn_i_01) = dyn_tmp_01;
         end
     case { '.xls', '.xlsx' }
-        [num,txt,raw] = xlsread(fullname,xls_sheet,xls_range); % Octave needs the extension explicitly
+        [freq,init,data,varlist] = load_xls_file_data(fullname,xls_sheet,xls_range);
         for dyn_i_01=1:var_size_01
-            iv = strmatch(var_names_01(dyn_i_01,:),raw(1,:),'exact');
-            dyn_tmp_01 = [raw{2:end,iv}]';
-            if length(dyn_tmp_01) > dyn_size_01 && dyn_size_01 > 0
+            iv = strmatch(strtrim(var_names_01(dyn_i_01,:)),varlist,'exact');
+            if ~isempty(iv)
+                dyn_tmp_01 = [data(2:end,iv)]';
+                if length(dyn_tmp_01) > dyn_size_01 && dyn_size_01 > 0
+                    cd(old_pwd)
+                    error('data size is too large')
+                end
+                dyn_data_01(:,dyn_i_01) = dyn_tmp_01;
+            else
                 cd(old_pwd)
-                error('data size is too large')
+                error([strtrim(var_names_01(dyn_i_01,:)) ' not found in ' fullname])
+            end
+        end
+    case '.csv'
+        [freq,init,data,varlist] = load_csv_file_data(fullname);
+        %var_names_01 = deblank(var_names_01);
+        for dyn_i_01=1:var_size_01
+            iv = strmatch(strtrim(var_names_01(dyn_i_01,:)),varlist,'exact');
+            if ~isempty(iv)
+                dyn_tmp_01 = [data(2:end,iv)]';
+                if length(dyn_tmp_01) > dyn_size_01 && dyn_size_01 > 0
+                    cd(old_pwd)
+                    error('data size is too large')
+                end
+                dyn_data_01(:,dyn_i_01) = dyn_tmp_01;
+            else
+                cd(old_pwd)
+                error([strtrim(var_names_01(dyn_i_01,:)) ' not found in ' fullname])
             end
-            dyn_data_01(:,dyn_i_01) = dyn_tmp_01;
         end
     otherwise
         cd(old_pwd)
