@@ -38,6 +38,10 @@ elseif options_.order == 3
     options_.k_order_solver = 1;
 end
 
+% if options_.loglinear == 1 && options_.periods>0
+%    error('The loglinear option does not work with periods>0.')
+% end
+
 if isempty(options_.qz_criterium)
     options_.qz_criterium = 1+1e-6;
 end
@@ -77,9 +81,18 @@ elseif options_.discretionary_policy
     end
     [oo_.dr,ys,info] = discretionary_policy_1(oo_,options_.instruments);
 else
+    if options_.logged_steady_state
+        oo_.dr.ys=exp(oo_.dr.ys);
+        oo_.steady_state=exp(oo_.steady_state);
+    end
     [oo_.dr,info,M_,options_,oo_] = resol(0,M_,options_,oo_);
 end
 
+if options_.loglinear
+    oo_.dr.ys=log(oo_.dr.ys);
+    oo_.steady_state=log(oo_.steady_state);
+    options_old.logged_steady_state = 1;
+end
 if info(1)
     options_ = options_old;
     print_info(info, options_.noprint, options_);
